@@ -217,7 +217,22 @@ class LambdaToStepfunctions(
         :summary: Constructs a new instance of the LambdaToStepfunctionsProps class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToStepfunctions.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToStepfunctionsProps(
@@ -313,7 +328,20 @@ class LambdaToStepfunctionsProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(LambdaToStepfunctionsProps.__init__)
+            def stub(
+                *,
+                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                deploy_vpc: typing.Optional[builtins.bool] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
